package com.example.mylog;


import java.text.SimpleDateFormat;
import java.util.Date;
import android.app.Service;
import android.content.Intent;
import android.database.Cursor;
import android.os.IBinder;
import android.provider.CallLog;
import android.util.Log;



public class CallHistory extends Service {

	//////////////////// Declaration of variables //////////////////////
	
	// Declare database + Log-tag
	private static final String TAG = CallHistory.class.getSimpleName();
	public DBAdapter callhistory;
	
	// Declare all values, which need to be logged
	String date, time, name, phonenumber, duration, callclassification;
	
	// Declare temporary variables (place-holders)
	String tmp1, tmp2;
	

	
	//////////////////// Formatting Methods of time/date/duration/call-type //////////////////////

	
	// Specify formatting of data and time --> looks awesome now :D
	SimpleDateFormat formatdate = new SimpleDateFormat("dd-MM-yyyy");
	SimpleDateFormat formattime = new SimpleDateFormat("HH:mm:ss");
	
	
    // Specify formatting for duration --> looks even more awesome :D    
    public String formatDuration(String input) {
        
        long seconds = Long.parseLong(input);
        StringBuffer buf = new StringBuffer();

        int h = (int) Math.floor(seconds / 3600);
        int m = (int) Math.floor((seconds - h * 3600) / 60);
        int s = (int) seconds - h - m;

        buf
            .append(String.format("%02d", h))
            .append(":")
            .append(String.format("%02d", m))
            .append(":")
            .append(String.format("%02d", s));

        return buf.toString();
    }
    
    // Specify interpretation of Call-Type
    public String callType(String t)    {
        
    	String g = null;

		if ("1".equals(t))	g = "Incoming Call";
		else if ("2".equals(t))	g = "Outgoing Call";
		else if ("3".equals(t))	g = "Missed Call";

		return g;
    }


	
	@Override
	public IBinder onBind(Intent intent) {
		return null;
	}
	
	@Override
	public void onCreate() {
		super.onCreate();
		  		
		// Create Database	
    	callhistory = new DBAdapter(getApplicationContext());

		Log.d(TAG, "Collecting Call History");
		
	    Cursor c = getContentResolver().query(
	               android.provider.CallLog.Calls.CONTENT_URI,
	               null,
	               null,
	               null,
	               android.provider.CallLog.Calls.DATE + " DESC");

		
	    if(c.moveToFirst()) {
			
			// Open Database
			callhistory.open();
			
			// Iteration-variable;
			int i = 1;

			// Check: Still valid entry left?
			while(!c.isAfterLast()) {		
				
				// Collect History
			    long tmp = c.getLong(c.getColumnIndex(CallLog.Calls.DATE));
			    Date d = new Date(tmp);
			    date = formatdate.format(d);
			    time = formattime.format(d);
			    name = c.getString(c.getColumnIndex(CallLog.Calls.CACHED_NAME));
			    phonenumber = c.getString(c.getColumnIndex(CallLog.Calls.NUMBER));
			    tmp1 = c.getString(c.getColumnIndex(CallLog.Calls.DURATION));
			    duration = formatDuration(tmp1);
			 	tmp2 = c.getString(c.getColumnIndex(CallLog.Calls.TYPE));
			 	callclassification = callType(tmp2);
			    
			    	    
			 	// Log History
			    Log.d(TAG, "Entry number: " + i);
			 	Log.d(TAG, date);
			  	Log.d(TAG, time);
			  	Log.d(TAG, name);
			  	Log.d(TAG, phonenumber);
			  	Log.d(TAG, duration);
			  	Log.d(TAG, callclassification);
				

			  	// Write History
				callhistory.insertCallLogs(date, time, name, phonenumber, duration, callclassification);

			  			  	
			  	// Move to the next entry
				c.moveToNext();	
				i++;
			}
			
		}

		c.close();	  	
		callhistory.close();
	   
		
		//////////////////////// End of Call History Collection //////////////////////////
		// Kill this Service //
		//Log.d(TAG, "Killing Service!");
		//onDestroy();
	}
	
	
}